<h6 align="left">
    <img src="https://cdnquakingaspen.s3.eu-central-1.amazonaws.com/quaking+aspen+logo+teal+full-02.png"  />
</h6>

# AWS_SMS_Service
[Introduction](#Introduction)\
[Getting Started](#Started)\
[Example](#Example)\
[Contributors](#Contributors)\
[License](#License)

<h2 id="Introduction">Introduction</h2>
his library is to help send sms using AWS sms service

<h2 id="Started">Getting Started</h2>
In order to install, open the command prompt and type ✌️:

```
pip install aws_sms_service
```

<h2 id="Example">Example</h2>

The following directory [Example](https://github.com/Quakingaspen-codehub/aws_sms_service/blob/master/aws_sms_service/example.py) shows a multiple example about how to use webhook_manager modules


<h2 id="">Contributors</h2>

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/Quakingaspen-codehub/aws_sms_service/graphs/contributors">
""
</a>

<h2 id="License">License</h2>

This library is licensed under the MIT License - see the [LICENSE.md](LICENSE) file for details.
